@@ -1,7 +1,7 @@
 ;;; lao.el --- Quail package for inputting Lao characters  -*-coding: iso-2022-7bit;-*-
 
 ;; Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
-;;   2006, 2007
+;;   2006, 2007, 2008, 2009, 2010, 2011
 ;;   National Institute of Advanced Industrial Science and Technology (AIST)
 ;;   Registration Number H14PRO021
 
@@ -9,10 +9,10 @@
 
 ;; This file is part of GNU Emacs.
 
-;; GNU Emacs is free software; you can redistribute it and/or modify
+;; GNU Emacs is free software: you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2, or (at your option)
-;; any later version.
+;; the Free Software Foundation, either version 3 of the License, or
+;; (at your option) any later version.
 
 ;; GNU Emacs is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,9 +20,7 @@
 ;; GNU General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-;; Boston, MA 02110-1301, USA.
+;; along with GNU Emacs.  If not, see <http://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 
@@ -206,10 +204,10 @@ you need to re-load it to properly re-initialize related alists.")
 		lao-tone-key-alist
 		lao-other-key-alist)
     (svt-state (lao-semivowel-key-alist . v-state)
-	      (lao-vowel-key-alist . t-state)
-	      lao-voweltone-key-alist)
+	       (lao-vowel-key-alist . t-state)
+	       lao-voweltone-key-alist
+	       lao-tone-key-alist)
     (v-state (lao-vowel-key-alist . t-state))
     (t-state lao-tone-key-alist))))
 
-;;; arch-tag: 23863a30-a8bf-402c-b7ce-c517a7aa8570
 ;;; lao.el ends here
